@@ -56,7 +56,7 @@ FAILEDOPERATION_IMAGENOTEXT = 'FailedOperation.ImageNoText'
 # 图片尺寸过大，请参考输出参数中关于图片大小限制的说明。
 FAILEDOPERATION_IMAGESIZETOOLARGE = 'FailedOperation.ImageSizeTooLarge'
 
-# 发票数据不一致。
+# 发票数据不一致。温馨提示：新版发票核验接口功能更完整，请尽快切换，如已切换请忽略。
 FAILEDOPERATION_INVOICEMISMATCH = 'FailedOperation.InvoiceMismatch'
 
 # 输入的Language不支持。
@@ -101,14 +101,35 @@ INVALIDPARAMETER_INVALIDGTINERROR = 'InvalidParameter.InvalidGTINError'
 # 参数值错误。
 INVALIDPARAMETERVALUE_INVALIDPARAMETERVALUELIMIT = 'InvalidParameterValue.InvalidParameterValueLimit'
 
+# 开票金额或校验码参数值错误。
+INVALIDPARAMETERVALUE_PRICEORVERIFICATIONPARAMETERVALUELIMIT = 'InvalidParameterValue.PriceOrVerificationParameterValueLimit'
+
+# 发票代码参数值错误。
+INVALIDPARAMETERVALUE_TICKETCODEPARAMETERVALUELIMIT = 'InvalidParameterValue.TicketCodeParameterValueLimit'
+
+# 开票日期参数值错误。
+INVALIDPARAMETERVALUE_TICKETDATEPARAMETERVALUELIMIT = 'InvalidParameterValue.TicketDateParameterValueLimit'
+
+# 发票号码参数值错误。
+INVALIDPARAMETERVALUE_TICKETSNPARAMETERVALUELIMIT = 'InvalidParameterValue.TicketSnParameterValueLimit'
+
 # 文件内容太大。
 LIMITEXCEEDED_TOOLARGEFILEERROR = 'LimitExceeded.TooLargeFileError'
 
-# 发票不存在。
+# 请求的次数超过了频率限制。
+REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'
+
+# 地区编码不存在。
+RESOURCENOTFOUND_NOAREACODE = 'ResourceNotFound.NoAreaCode'
+
+# 发票不存在。温馨提示：新版发票核验接口功能更完整，请尽快切换，如已切换请忽略。
 RESOURCENOTFOUND_NOINVOICE = 'ResourceNotFound.NoInvoice'
 
 # 不支持当天发票查询。
 RESOURCENOTFOUND_NOTSUPPORTCURRENTINVOICEQUERY = 'ResourceNotFound.NotSupportCurrentInvoiceQuery'
 
+# 税务局网络异常，请稍后访问。
+RESOURCEUNAVAILABLE_TAXNETWORKERROR = 'ResourceUnavailable.TaxNetworkError'
+
 # 计费状态异常。
 RESOURCESSOLDOUT_CHARGESTATUSEXCEPTION = 'ResourcesSoldOut.ChargeStatusException'
